@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
-# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011  Andrey Golovizin
-# 
+# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011, 2012  Andrey Golovizin
+#
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
 # "Software"), to deal in the Software without restriction, including
@@ -9,10 +9,10 @@
 # distribute, sublicense, and/or sell copies of the Software, and to
 # permit persons to whom the Software is furnished to do so, subject to
 # the following conditions:
-# 
+#
 # The above copyright notice and this permission notice shall be
 # included in all copies or substantial portions of the Software.
-# 
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 # EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
@@ -46,6 +46,16 @@ It is also possible to define bibliography formatting styles in Python.
 
     options = (
         (None, (
+            make_option(
+                '--min-crossrefs',
+                type='int', dest='min_crossrefs',
+                help='include item after NUMBER crossrefs; default 2',
+                metavar='NUMBER',
+            ),
+            make_option(
+                '--terse', dest='verbose', action='store_false',
+                help='ignored for compatibility with BibTeX',
+            ),
             make_option(
                 '-f', '--bibliography-format', dest='bib_format',
                 help='bibliograpy format (%plugin_choices)',
@@ -65,6 +75,8 @@ It is also possible to define bibliography formatting styles in Python.
                 help='style definition language to use (bibtex or python)',
                 metavar='LANGUAGE',
             ),
+        )),
+        ('Pythonic style options', (
             make_option(
                 '--label-style', dest='label_style',
                 help='label formatting style (%plugin_choices)',
@@ -79,22 +91,19 @@ It is also possible to define bibliography formatting styles in Python.
                 plugin_group='pybtex.style.names',
                 metavar='STYLE',
             ),
+            make_option(
+                '--sorting-style', dest='sorting_style',
+                help='sorting style (%plugin_choices)',
+                type='load_plugin',
+                plugin_group='pybtex.style.sorting',
+                metavar='STYLE',
+            ),
             make_option(
                 '--abbreviate-names',
                 action='store_true', dest='abbreviate_names',
                 help='use abbreviated name formatting style',
             ),
-            make_option(
-                '--min-crossrefs',
-                type='int', dest='min_crossrefs',
-                help='include item after NUMBER crossrefs; default 2',
-                metavar='NUMBER',
-            ),
-            make_option(
-                '--terse', dest='verbose', action='store_false',
-                help='ignored for compatibility with BibTeX',
-            )
-    )),
+        )),
         ('Encoding options', (
             make_option(
                 '-e', '--encoding', dest='encoding', metavar='ENCODING',
@@ -123,32 +132,16 @@ It is also possible to define bibliography formatting styles in Python.
             'output_backend': 'output backends',
             'label_style': 'label styles',
             'name_style': 'name styles',
+            'sorting_style': 'sorting styles',
             'abbreviate_names': 'abbreviated names',
         }
         if options.style_language != 'python':
-            for option, what_is_not_supported in not_supported_by_bibtex.items():
+            for option, what_is_not_supported in not_supported_by_bibtex.iteritems():
                 if getattr(options, option):
                     self.opt_parser.error(
                         '%s are only supported by the Pythonic style engine (-l python)' % what_is_not_supported
                     )
 
-
-        kwargs = {}
-        if options.label_style:
-            kwargs['label_style'] = find_plugin('pybtex.style.labels', options.label_style)
-        if options.name_style:
-            kwargs['name_style'] = find_plugin('pybtex.style.names', options.name_style)
-        if options.output_backend:
-            kwargs['output_backend'] = find_plugin('pybtex.backends', options.output_backend)
-        if options.bib_format:
-            kwargs['bib_format'] = find_plugin('pybtex.database.input', options.bib_format)
-        kwargs['abbreviate_names'] = bool(options.abbreviate_names)
-        kwargs['min_crossrefs'] = options.min_crossrefs
-        for option in ('bib_encoding', 'output_encoding', 'bst_encoding'):
-            value = getattr(options, option) or options.encoding
-            if value:
-                kwargs[option] = value
-
         if options.style_language == 'bibtex':
             from pybtex import bibtex as engine
         elif options.style_language == 'python':
@@ -156,6 +149,16 @@ It is also possible to define bibliography formatting styles in Python.
         else:
             self.opt_parser.error('unknown style language %s' % options.style_language)
 
+        for encoding_option in 'bib_encoding', 'bst_encoding', 'output_encoding':
+            if not getattr(options, encoding_option):
+                setattr(options, encoding_option, options.encoding)
+
+        kwargs = {}
+        uninteresting_options = 'verbose', 'style_language'
+        kwargs = dict(
+            (key, value) for (key, value) in options.__dict__.iteritems()
+            if key not in uninteresting_options
+        )
         engine.make_bibliography(filename, **kwargs)
 
 main = PybtexCommandLine()
