@@ -1,5 +1,5 @@
-# Copyright (c) 2008, 2009, 2010, 2011  Andrey Golovizin
-# 
+# Copyright (c) 2008, 2009, 2010, 2011, 2012  Andrey Golovizin
+#
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
 # "Software"), to deal in the Software without restriction, including
@@ -7,10 +7,10 @@
 # distribute, sublicense, and/or sell copies of the Software, and to
 # permit persons to whom the Software is furnished to do so, subject to
 # the following conditions:
-# 
+#
 # The above copyright notice and this permission notice shall be
 # included in all copies or substantial portions of the Software.
-# 
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 # EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
@@ -55,7 +55,7 @@ class Backend(BaseBackend):
         tag = self.tags[tag_name]
         return ur'<%s>%s</%s>' % (tag, text, tag)
     
-    def write_prologue(self, maxlen):
+    def write_prologue(self):
         encoding = self.encoding or pybtex.io.get_default_encoding()
         self.output(PROLOGUE % encoding)
 
