@@ -1,5 +1,5 @@
-# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011  Andrey Golovizin
-# 
+# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011, 2012  Andrey Golovizin
+#
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
 # "Software"), to deal in the Software without restriction, including
@@ -7,10 +7,10 @@
 # distribute, sublicense, and/or sell copies of the Software, and to
 # permit persons to whom the Software is furnished to do so, subject to
 # the following conditions:
-# 
+#
 # The above copyright notice and this permission notice shall be
 # included in all copies or substantial portions of the Software.
-# 
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 # EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
@@ -55,9 +55,34 @@ class Writer(BaseWriter):
             return '{%s}' % s
 
     def check_braces(self, s):
-        end_brace_level = list(scan_bibtex_string(s))[-1][1]
-        if end_brace_level != 0:
-            raise BibTeXError('String has unmatched braces: %s' % s)
+        """
+        Raise an exception if the given string has unmatched braces.
+
+        >>> w = Writer()
+        >>> w.check_braces('Cat eats carrots.')
+        >>> w.check_braces('Cat eats {carrots}.')
+        >>> w.check_braces('Cat eats {carrots{}}.')
+        >>> w.check_braces('')
+        >>> w.check_braces('end}')
+        >>> try:
+        ...     w.check_braces('{')
+        ... except BibTeXError, error:
+        ...     print error
+        String has unmatched braces: {
+        >>> w.check_braces('{test}}')
+        >>> try:
+        ...     w.check_braces('{{test}')
+        ... except BibTeXError, error:
+        ...     print error
+        String has unmatched braces: {{test}
+
+        """
+
+        tokens = list(scan_bibtex_string(s))
+        if tokens:
+            end_brace_level = tokens[-1][1]
+            if end_brace_level != 0:
+                raise BibTeXError('String has unmatched braces: %s' % s)
 
     def write_stream(self, bib_data, stream):
         def write_field(type, value):
