@@ -1,5 +1,5 @@
-# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011  Andrey Golovizin
-# 
+# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011, 2012  Andrey Golovizin
+#
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
 # "Software"), to deal in the Software without restriction, including
@@ -7,10 +7,10 @@
 # distribute, sublicense, and/or sell copies of the Software, and to
 # permit persons to whom the Software is furnished to do so, subject to
 # the following conditions:
-# 
+#
 # The above copyright notice and this permission notice shall be
 # included in all copies or substantial portions of the Software.
-# 
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 # EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
@@ -74,12 +74,20 @@ class Text(list):
 
     Text is used as an internal formatting language of Pybtex,
     being rendered to to HTML or LaTeX markup or whatever in the end.
+
+    >>> Text()
+    []
+    >>> Text('a', '', 'c')
+    ['a', 'c']
+    >>> Text('a', Text(), 'c')
+    ['a', 'c']
+
     """
 
     def __init__(self, *parts):
         """Create a Text consisting of one or more parts."""
 
-        list.__init__(self, parts)
+        list.__init__(self, [part for part in parts if part])
 
     def __len__(self):
         """Return the number of characters in this Text."""
@@ -125,7 +133,7 @@ class Text(list):
                 text.append(backend.format_text(item))
             else:
                 text.append(item.render(backend))
-        return "".join(text)
+        return backend.render_sequence(text)
 
     def enumerate(self):
         for n, child in enumerate(self):
@@ -205,7 +213,12 @@ class Text(list):
         return ''.join(unicode(l[i]) for l, i in self.enumerate())
 
     def capfirst(self):
-        """Capitalize the first letter of the text"""
+        """Capitalize the first letter of the text.
+
+        >>> Text(Text(), Text('mary ', 'had ', 'a little lamb')).capfirst()
+        [['Mary ', 'had ', 'a little lamb']]
+
+        """
         return self.apply_to_start(textutils.capfirst)
 
     def add_period(self, period='.'):
