@@ -1,5 +1,5 @@
-# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011  Andrey Golovizin
-# 
+# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011, 2012  Andrey Golovizin
+#
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
 # "Software"), to deal in the Software without restriction, including
@@ -7,10 +7,10 @@
 # distribute, sublicense, and/or sell copies of the Software, and to
 # permit persons to whom the Software is furnished to do so, subject to
 # the following conditions:
-# 
+#
 # The above copyright notice and this permission notice shall be
 # included in all copies or substantial portions of the Software.
-# 
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 # EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
@@ -19,5 +19,27 @@
 # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-from . import labels
-from . import names
+
+class FormattedEntry(object):
+    """Formatted bibliography entry. Consists of
+    - key (which is used for sorting);
+    - label (which appears in the resulting bibliography)
+    - text (usually RichText)
+    """
+    def __init__(self, key, text, label=None):
+        self.key = key
+        self.text = text
+        self.label = label
+
+
+class FormattedBibliography(object):
+    def __init__(self, entries, style):
+        self.entries = list(entries)
+        self.style = style
+
+    def __iter__(self):
+        return iter(self.entries)
+
+    def get_longest_label(self):
+        label_style = self.style.label_style
+        return label_style.get_longest_label(self.entries)
