@@ -1,7 +1,7 @@
 # vim:fileencoding=utf8
 
-# Copyright (c) 2008, 2009, 2010, 2011  Andrey Golovizin
-# 
+# Copyright (c) 2008, 2009, 2010, 2011, 2012  Andrey Golovizin
+#
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
 # "Software"), to deal in the Software without restriction, including
@@ -9,10 +9,10 @@
 # distribute, sublicense, and/or sell copies of the Software, and to
 # permit persons to whom the Software is furnished to do so, subject to
 # the following conditions:
-# 
+#
 # The above copyright notice and this permission notice shall be
 # included in all copies or substantial portions of the Software.
-# 
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 # EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
@@ -26,7 +26,7 @@ A template engine for bibliography entries and more.
 
 Inspired by Brevé -- http://breve.twisty-industries.com/
 
->>> from pybtex.core import Entry, Person
+>>> from pybtex.database import Entry, Person
 >>> author = Person(first='First', last='Last', middle='Middle')
 >>> fields = {
 ...         'title': 'The Book',
@@ -47,6 +47,7 @@ from pybtex.exceptions import PybtexError
 
 __test__ = {} # for doctest
 
+
 class Proto(object):
     def __init__(self, *args, **kwargs):
         self.args = args
@@ -148,14 +149,17 @@ def _format_data(node, data):
     else:
         return f(data)
 
+
 def _format_list(list_, data):
-    return [_format_data(part, data) for part in list_]
+    return (_format_data(part, data) for part in list_)
+
 
 def node(f):
     if f.__doc__:
         __test__[f.__name__] = f
     return Proto(f.__name__, f)
 
+
 @node
 def join(children, data, sep='', sep2=None, last_sep=None):
     """Join text fragments together.
@@ -181,12 +185,14 @@ def join(children, data, sep='', sep2=None, last_sep=None):
     else:
         return richtext.Text(last_sep).join([richtext.Text(sep).join(parts[:-1]), parts[-1]])
 
+
 @node
 def words(children, data, sep=' '):
     """Join text fragments with spaces or something else."""
 
     return join(sep) [children].format_data(data)
 
+
 @node
 def together(children, data, last_tie=True):
     """
@@ -231,10 +237,12 @@ def sentence(children, data, capfirst=True, add_period=True, sep=', '):
         text = text.add_period()
     return text
 
+
 class FieldIsMissing(PybtexError):
-    def __init__(self, field_name):
+    def __init__(self, field_name, entry):
         self.field_name = field_name
-        super(FieldIsMissing, self).__init__('missing field: %s' % field_name)
+        super(FieldIsMissing, self).__init__(
+            'missing field: %s in %s' % (field_name, entry))
 
 @node
 def field(children, data, name, apply_func=None):
@@ -244,30 +252,43 @@ def field(children, data, name, apply_func=None):
     try:
         field = data.fields[name]
     except KeyError:
-        raise FieldIsMissing(name)
+        raise FieldIsMissing(name, data)
     else:
         if apply_func:
             field = apply_func(field)
         return field
 
+
 @node
 def names(children, data, role, **kwargs):
     """Return formatted names."""
 
     assert not children
-    persons = data.persons[role]
+    try:
+        persons = data.persons[role]
+    except KeyError:
+        # role is a bibtex field so it makes sense
+        # to raise FieldIsMissing; optional will catch it
+        raise FieldIsMissing(role, data)
     return join(**kwargs) [[person.text for person in persons]].format_data(data)
 
+
 @node
 def optional(children, data):
     """If children contain a missing bibliography field, return None.
     Else return formatted children.
+
+    >>> from pybtex.database import Entry
+    >>> template = optional [field('volume'), optional['(', field('number'), ')']]
+    >>> print template.format_data(Entry('article'))
+    []
+
     """
 
     try:
         return richtext.Text(*_format_list(children, data))
     except FieldIsMissing:
-        return None
+        return richtext.Text()
 
 @node
 def optional_field(children, data, *args, **kwargs):
@@ -288,6 +309,7 @@ def tag(children, data, name):
     parts = _format_list(children, data)
     return richtext.Tag(name, *_format_list(children, data))
 
+
 @node
 def first_of(children, data):
     """Return first nonempty child."""
